import React, {Component} from 'react';
import PropTypes from 'prop-types';
import Form from './Form';
import Loading from './Loading';
import {Alert} from 'reactstrap';

class ManagerForm extends Component {
    static propTypes = {
        siteKey: PropTypes.string.isRequired,
        jsonForm: PropTypes.arrayOf(
            PropTypes.shape({
                validateOnChange: PropTypes.func,
                showCaptcha: PropTypes.bool,
                title: PropTypes.string,
                fields: PropTypes.arrayOf(PropTypes.shape({
                    disabled: PropTypes.bool
                })),
                buttons: PropTypes.arrayOf(PropTypes.shape())
            })
        ).isRequired,
        chapterNumber: PropTypes.number,
        tokenCaptcha: PropTypes.string,
        abmStatus: PropTypes.shape().isRequired,
        error: PropTypes.shape({}).isRequired
    };

    static defaultProps = {
        chapterNumber: 0,
        tokenCaptcha: ''
    };

    constructor(props) {
        super(props);
        this.state = {
            chapterNumber: this.props.chapterNumber,
            tokenCaptcha: this.props.tokenCaptcha,
            values: [{}]
        }
    }

    handleChapterNumber(number, currentValues) {
        this.state.values[this.state.chapterNumber] = currentValues;
        if (this.props.jsonForm[this.state.chapterNumber].showCaptcha) {
            this.state.tokenCaptcha = currentValues.tokenCaptcha;
        }
        this.setState({
            chapterNumber: number
        });
    }

    render(){
        const {jsonForm} = this.props;
        if(this.props.jsonForm.valuesUpdate){
            this.state.values[this.state.chapterNumber] = this.props.jsonForm.valuesUpdate[this.state.chapterNumber];
        }
        if (this.state.values[this.state.chapterNumber] === undefined) {
            if (this.props.jsonForm[this.state.chapterNumber].showCaptcha) {
                this.state.values[this.state.chapterNumber] = {
                    tokenCaptcha: this.state.tokenCaptcha
                };
            } else {
                this.state.values[this.state.chapterNumber] = {}
            }
        } else if (this.props.jsonForm[this.state.chapterNumber].showCaptcha) {
            this.state.values[this.state.chapterNumber].tokenCaptcha = this.state.tokenCaptcha;
        }

        // esto limpia el formulario cuando da success
        if(this.props.abmStatus.success){
            this.state.values[this.state.chapterNumber] = {};
        }
        const {abmStatus} = this.props;
        let showForm = true;
        if (abmStatus.success || abmStatus.sending){
            showForm = false;
        }
        return (
            <div>
                {abmStatus.success && (
                    <Alert color="success">
                        Alta realizada con exito. Aguarde un momento
                    </Alert>
                )}
                {abmStatus.sending && (
                    <Loading label="Aguarde por favor"/>
                )}
                {showForm && (
                    <Form
                        siteKey={this.props.siteKey}
                        error={this.props.error}
                        values={this.state.values[this.state.chapterNumber]}
                        onUpdateChapter={(number, currentValues) => this.handleChapterNumber(number, currentValues)}
                        chapter={jsonForm[this.state.chapterNumber]}
                        chapterNumber={this.state.chapterNumber}
                    />
                )}
            </div>
        );
    }
}

export default ManagerForm;

