import React from 'react';
import PropTypes from 'prop-types';
import {
    Pagination,
    PaginationItem,
    PaginationLink,
    Col,
    Row
} from 'reactstrap';
import {times, uniqueId} from 'lodash';

import {FontAwesomeIcon} from '@fortawesome/react-fontawesome';
import {
    faFastBackward,
    faStepBackward,
    faStepForward,
    faFastForward
} from '@fortawesome/free-solid-svg-icons';


uniqueId('pagination');

/**
 * @param {Object} Object
 * @param {Function} Object.handleQuery
 * @param {Number} Object.sizePagination
 * @param {Number} Object.current
 * @param {Number} Object.total
 * @param {Boolean} Object.total
 */
const PaginationComponent = ({
                      handleQuery,
                      sizePagination,
                      current,
                      total,
                      hideTotals,
                      isChart,
                      pageCount
                  }) => {
    const SIZE = isChart ? 20 : 15;
    const currentAmount = SIZE * (current + 1);
    const PAGE_SIZE_MINUS_ONE = SIZE - 1;
    const seeing = currentAmount > total ? total : currentAmount;
    return (
        <Row className="align-items-center">
            {!hideTotals && (
                <Col
                    sm="1"
                    md="1"
                >
                    <code>
                        <p style={{color: '#0057b3'}}>
                            { currentAmount > seeing ? currentAmount - PAGE_SIZE_MINUS_ONE : seeing - PAGE_SIZE_MINUS_ONE }
                            &nbsp;-&nbsp;
                            { seeing }
                            &nbsp;de&nbsp;
                            { total }
                        </p>
                    </code>
                </Col>
            )}
            <Col
                sm={{size: 10, offset: 1}}
                md={{size: 10, offset: 1}}
                className="align-self-center align-items-center"
            >
                <Pagination>
                    <PaginationItem>
                        <PaginationLink onClick={() => handleQuery({start: 0})}>
                            <FontAwesomeIcon icon={faFastBackward}/>
                        </PaginationLink>
                    </PaginationItem>
                    <PaginationItem>
                        <PaginationLink previous onClick={() => handleQuery(current - 1 < 0 ? {start: 0} : {start: current - 1})}>
                            <FontAwesomeIcon icon={faStepBackward}/>
                        </PaginationLink>
                    </PaginationItem>
                    {times((((total - 1) / sizePagination) + 1),
                        i => (
                            (i === current) || ((current - i < 8) && (current - i > 0)) || ((i - current < 8) && (i > current)) ? (
                                <PaginationItem
                                    key={uniqueId()}
                                    active={current === i}
                                >
                                    <PaginationLink
                                        onClick={() => handleQuery({start: i})}
                                        onTouchStart={() => handleQuery({start: i})}
                                    >
                                        { i + 1}
                                    </PaginationLink>
                                </PaginationItem>
                            ) : null))}
                    <PaginationItem>
                        <PaginationLink
                            next
                            onClick={() => handleQuery(current + 1 >= pageCount ? {start: current} : {start: current + 1})}
                        >
                            <FontAwesomeIcon icon={faStepForward}/>
                        </PaginationLink>
                    </PaginationItem>
                    <PaginationItem>
                        <PaginationLink
                            last
                            onClick={() => handleQuery({start: pageCount - 1})}
                        >
                            <FontAwesomeIcon icon={faFastForward}/>
                        </PaginationLink>
                    </PaginationItem>
                </Pagination>
            </Col>
        </Row>
    );
};

PaginationComponent.propTypes = {
    handleQuery: PropTypes.func.isRequired,
    sizePagination: PropTypes.number.isRequired,
    current: PropTypes.number.isRequired,
    total: PropTypes.number.isRequired,
    pageCount: PropTypes.number.isRequired,
    hideTotals: PropTypes.bool,
    isChart: PropTypes.bool
};

PaginationComponent.defaultProps = {
    hideTotals: false,
    isChart: false
};

export default PaginationComponent;
