import React, {Component} from 'react';
import {Row, Col, Button,  PopoverBody, UncontrolledPopover} from 'reactstrap';
import {includes, lowerCase, forEach} from 'lodash';
import PropTypes from 'prop-types';
import TextField from './TextField';
import SelectFilter from "./SelectFilter";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faTimes, faSyncAlt, faSearch} from "@fortawesome/free-solid-svg-icons";
import {iconStyle, noPadding} from "../styles";

class SpecialFilters extends Component {
    static filterOption(option, inputValue) {
        return includes(lowerCase(option.label), lowerCase(inputValue))
            || includes(option.label, 'Sin Asignar');
    }

    static propTypes = {
        headers: PropTypes.arrayOf(PropTypes.shape).isRequired,
        onSearch: PropTypes.func.isRequired,
        onChange: PropTypes.func.isRequired,
        onChangeView: PropTypes.func.isRequired,
        active: PropTypes.func.isRequired,
        onCleanSearch: PropTypes.func.isRequired,
        seeker: PropTypes.arrayOf().isRequired
    };

    constructor(props) {
        super(props);
        this.state = {
            filter: '',
            optionFilters: this.makeOptionFilter()
        };
    }

    makeOptionFilter() {
        const options = [];
        forEach(this.props.headers, function(value, key){
            if (value) {
                options.push({
                    label: value,
                    value: key
                });
            }
        });
        return options;
    }

    handleChange(e, select) {
        if (select) {
            if (e !== undefined) {
                this.setState({
                    [select]: e
                });
            }
        }
    }

    handlerOnSearch(e) {
        this.props.onSearch(e,this.state.filter.value);
    }

    handleChangeView(){
        this.props.onChangeView();
    }

    handleCleanSearch(){
        this.props.onCleanSearch();
    }

    render() {
        return (
            <div>
                <Row className="d-flex justify-content-start">
                    <Col sm="4" className="pl-0">
                        <SelectFilter
                            label="Filtra por"
                            control="filter"
                            placeholder="Campo de busqueda"
                            value={this.state.filter}
                            onChange={e => this.handleChange(e, 'filter')}
                            options={this.state.optionFilters}
                            filterOption={SpecialFilters.filterOption}
                        />
                    </Col>
                    <Col sm="4" className="pl-0">
                        <TextField
                            control="newSeeker"
                            label="Valor"
                            placeholder="Valor de busqueda"
                            value={this.props.seeker}
                            onChange={e => this.props.onChange(e.target)}
                        />
                    </Col>
                    <Col sm="4" className="pl-0" style={{marginTop: '21px'}}>
                        <Row>
                            <Button
                                type="submit"
                                color="primary"
                                onClick={e => this.handlerOnSearch(e)}
                            >
                                Buscar
                                &nbsp;
                                <FontAwesomeIcon icon={faSearch} style={{iconStyle, ...noPadding}}/>
                            </Button>
                            &nbsp;
                            <Button
                                id="Change"
                                children={this.props.active === 'S' ? 'Activos': 'Inactivos'}
                                color={this.props.active === 'S' ? "success" : "danger"}
                                onClick={() => this.handleChangeView()}>
                                {this.props.active === 'S'? "Activos" : "Inactivos"}
                                &nbsp;
                                <FontAwesomeIcon icon={faSyncAlt}
                                                 color={this.props.active === 'S' ? "success" : "danger"}
                                                 style={{iconStyle, ...noPadding}}/>
                            </Button>
                            <UncontrolledPopover
                                target="Change"
                                placement="top"
                                trigger="hover"
                            >
                                <PopoverBody>
                                    {this.props.active === 'S'?
                                        "Cambiar a la vista de inactivos":
                                        "Cambiar a la vista de activos"
                                    }
                                </PopoverBody>
                            </UncontrolledPopover>
                            &nbsp;
                            <Button
                                id="Clean"
                                color="secondary"
                                onClick={() => this.handleCleanSearch()}>
                                Limpiar
                                &nbsp;
                                <FontAwesomeIcon icon={faTimes} style={{iconStyle, ...noPadding}}/>
                            </Button>
                            <UncontrolledPopover
                                target="Clean"
                                placement="top"
                                trigger="hover"
                            >
                                <PopoverBody>
                                    Limpia la busqueda actual
                                </PopoverBody>
                            </UncontrolledPopover>
                        </Row>
                    </Col>
                </Row>
                <div>
                    <hr/>
                </div>
            </div>
        );
    }
}

export default SpecialFilters;
